﻿©Fluke                                                      MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Tek AFG3000 Remote Interface Connection
DATE:                  2010-06-04 11:49:15
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       158
=============================================================================
#
#  Procedure Author:
#        ZY
#
#  Models covered:
#        AFG 3000 series
#
#  Compatibility:
#        MET/CAL 7.20 SP1 (7.20x) or later
#
#  Subprocedures:
#        None
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  HEAD         REMOTE INTERFACE CONNECTION
# Initialize interface variables not specified in the calling procedure.
  1.002  IF           NOT(ISVAR("@VisaUSB"))
  1.003  MATH         @VisaUSB = 0
  1.004  ENDIF

  1.005  IF           NOT(ISVAR("@VisaLAN"))
  1.006  MATH         @VisaLAN = 0
  1.007  ENDIF

  1.008  IF           NOT(ISVAR("@VisaGPIB"))
  1.009  MATH         @VisaGPIB = 0
  1.010  ENDIF

# Make sure at least one support interface was specified.
  1.011  IF           NOT(@VisaUSB || @VisaLAN || @VisaGPIB)
  1.012  DISP         Either @VisaUSB or @VisaLAN or @VisaGPIB interface
  1.012  DISP         must be specified!
  1.013  MATH         @Abort = 1
  1.014  ENDIF

  1.015  MATH         USB = 0; LAN = 0; GPIB = 0

# If only one interface is supported by the UUT, choose it.
  1.016  IF           @VisaUSB && NOT(@VisaLAN) && NOT(@VisaGPIB)
  1.017  MATH         USB = 1

  1.018  ELSEIF       @VisaLAN && NOT(@VisaUSB) && NOT(@VisaGPIB)
  1.019  MATH         LAN = 1

  1.020  ELSEIF       @VisaGPIB && NOT(@VisaUSB) && NOT(@VisaLAN)
  1.021  MATH         GPIB = 1

# Otherwise allow operator to select the UUT interface to use.
  1.022  ELSE
  1.023  MATH         @Id = LBNEW("UUT REMOTE CONTROL INTERFACE")
  1.024  MEM2         =Select UUT interface to be used for calibration.
  1.025  MATH         LBTEXT(@Id, MEM2)
  1.026  MATH         LBCONF(@Id, "+SelReq")
  1.027  MATH         LBBUTTON(@Id, "OK")
  1.028  MATH         LBBUTTON(@Id, "Exit")

  1.029  IF           @VisaUSB
  1.030  MATH         LBADDV(@Id, "USB", "USB")
  1.031  ENDIF

  1.032  IF           @VisaLAN
  1.033  MATH         LBADDV(@Id, "LAN (Ethernet)", "LAN")
  1.034  ENDIF

  1.035  IF           @VisaGPIB
  1.036  MATH         LBADDV(@Id, "GPIB", "GPIB")
  1.037  ENDIF

# Return now if operator selected "Exit".
  1.038  IF           LBSHOW(@Id) == 2
  1.039  MATH         @Abort = 1
  1.040  END
  1.041  ENDIF

  1.042  ENDIF

# Display an appropriate message based on the UUT interface selected.
  1.043  IF           USB
  1.044  DISP         Using a USB Type A (Host) to USB Type B (Device) cable,
  1.044  DISP         connect an available PC USB port to the UUT (USB) DEVICE
  1.044  DISP         connector (on rear).
  1.044  DISP
  1.044  DISP         Ensure the Windows® operating system recognizes the
  1.044  DISP         "plug-and-play" device prior to proceeding.

  1.045  DISP         Configure the UUT for USB operation in accordance
  1.045  DISP         with instructions in the Tektronix AFG3000 Series
  1.045  DISP         Oscilloscopes User Manual.
  1.045  DISP
  1.045  DISP         Optionally, NI® Measurement & Automation Explorer (MAX)
  1.045  DISP         may be used to verify the USB connection, following the
  1.045  DISP         operating system's recognition of the device.

  1.046  ELSEIF       LAN
  1.047  DISP         Using an appropriate cable, connect the LAN (Ethernet,
  1.047  DISP         TCP/IP) to the UUT LAN Non-Auto-MDIX connector (rear).

  1.048  DISP         Configure the UUT for LAN operation in accordance
  1.048  DISP         with instructions in the Tektronix AFG3000 Series
  1.048  DISP         Oscilloscopes User Manual.

  1.049  DISP         NI® Measurement & Automation Explorer (MAX) MUST be used
  1.049  DISP         to establish a VISA resource name for the UUT, prior to
  1.049  DISP         proceeding.
  1.049  DISP
  1.049  DISP         Optionally, NI MAX may also be used to subsequently
  1.049  DISP         verify the UUT connection.

  1.050  ELSEIF       GPIB
  1.051  DISP         Using a GPIB cable, connect the PC GPIB port to UUT
  1.051  DISP         GPIB connector (on rear).

  1.052  DISP         Configure the UUT for GPIB operation in accordance
  1.052  DISP         with instructions in the Tektronix AFG3000 Series
  1.052  DISP         Oscilloscopes User Manual.
  1.052  DISP
  1.052  DISP         Optionally, NI® Measurement & Automation Explorer (MAX)
  1.052  DISP         may be used to verify the GPIB connection, following the
  1.052  DISP         operating system's recognition of the device.

  1.053  ENDIF

  1.054  MATH         @Abort = 0
  1.055  END
